#!/bin/bash

# Variables
Green='\033[0;32m'
Red='\033[0;31m'
NoColor='\033[0m'
AddonName='premium_reports_app'
AddonString="Premium Reports"
AddonVersionName='PREMIUM_REPORTS_VERSION'
###########

# Functions
EULA() {
  if [ -z "${Answer}" ];then
    while read -r Line
    do
      printf '%s\n' "${Line}"
    done < EULA.txt|more
  fi
  while [ -z "${Answer}" ];do
    read -p "You declare you have successfully read and accepted the EULA (End User License Agreement), present in EULA.txt file, and all its terms and conditions, for the software you are attempting to install [Y/y/N/n]: " Answer
    case ${Answer} in
      Y|y)
        Answer="yes"
      ;;
      N|n)
        Answer="no"
      ;;
      *)
        Answer=""
      ;;
    esac
  done
  if [ "${Answer}" == "yes" ];then
    printf "${Green}*** [${AddonName}] EULA accepted. Proceeding with installation...${NoColor}\n"
  else
    printf "${Red}*** [${AddonName}] EULA not accepted. Exiting...${NoColor}\n"
    exit 0
  fi
}

Install() {
  OMLDirectory="/opt/omnileads/ominicontacto"
  OMLBinDirectory="/opt/omnileads/bin"
  mkdir -p ${OMLDirectory}/${AddonName}
  printf "${Green}*** [${AddonName}] Checking OMniLeads version...${NoColor}\n"
  OMLVersion=`cat ${OMLDirectory}/ominicontacto_app/version.py|grep OML_BRANCH|awk -F "=" '{gsub(/"/, "", $2); print $2}'`
  if [[ ${OMLVersion} == *"release-1.2"* ]] || [[ ${OMLVersion} == *"release-1.3"* ]];then
    printf "${Red}*** [${AddonName}] OMniLeads version not supported to install this addon. Please, first upgrade your instance.${NoColor}\n"
    exit 1
  fi
  AddonsInstalled="`cat ${OMLDirectory}/../bin/addons_installed.sh > /dev/null 2>&1`"
  if [[ ${AddonsInstalled} != *"${AddonName}"* ]];then
    printf "${Green}*** [${AddonName}] Modifying variable ADDONS_INSTALLED...${NoColor}\n"
    echo "ADDONS_INSTALLED+=('${AddonName}')" >> ${OMLDirectory}/../bin/addons_installed.sh
    chown -R omnileads. ${OMLDirectory}/../bin/addons_installed.sh
  fi
  printf "${Green}*** [${AddonName}] Copying the ${AddonName} folder to ${OMLDirectory}...${NoColor}\n"
  AddonRelease=$(ls -d */|grep -v docs|rev|cut -c 2-|rev)
  rm -rf ${OMLDirectory}/${AddonName}
  if [ ! -d ${OMLDirectory}/${AddonName} ];then
    mkdir ${OMLDirectory}/${AddonName}
  fi
  cp -a ${AddonRelease}/* ${OMLDirectory}/${AddonName}
  source /etc/profile.d/omnileads_envars.sh
  AddonEnvar="`grep "${AddonVersionName}=" /etc/profile.d/omnileads_envars.sh`"
  if [ -z ${AddonEnvar} ];then
    printf "${Green}*** [${AddonName}] Adding the ${AddonName} version to omnileads_envars.sh...${NoColor}\n"
    sed -i "/^export.*/i ${AddonVersionName}=${AddonRelease}" /etc/profile.d/omnileads_envars.sh
    sed -i '$s/$/ '${AddonVersionName}'/' /etc/profile.d/omnileads_envars.sh
  else
    sed -i "s/^${AddonVersionName}.*/${AddonVersionName}=${AddonRelease}/g" /etc/profile.d/omnileads_envars.sh
  fi

  printf "${Green}*** [${AddonName}] Executing django commands...${NoColor}\n"
  ${OMLBinDirectory}/manage.sh collectstatic --noinput > /dev/null 2>&1
  ResultCommand1=`echo $?`
  ${OMLBinDirectory}/manage.sh collectstatic_js_reverse > /dev/null 2>&1
  ResultCommand2=`echo $?`
  ${OMLBinDirectory}/manage.sh compress --force > /dev/null 2>&1
  ResultCommand3=`echo $?`
  ${OMLBinDirectory}/manage.sh actualizar_permisos > /dev/null 2>&1
  ResultCommand4=`echo $?`
  ${OMLBinDirectory}/manage.sh compilemessages > /dev/null 2>&1
  ResultCommand5=`echo $?`
  chown -R omnileads. ${OMLDirectory}
  if [ ${ResultCommand1} == 0 ] && [ ${ResultCommand2} == 0 ] && [ ${ResultCommand3} == 0 ] && [ ${ResultCommand4} == 0 ] && [ ${ResultCommand5} == 0 ];then
    printf "${Green}*** [${AddonName}] OMniLeads ${AddonString} Addon installed successfully.${NoColor}\n"
    printf "${Green}*** [${AddonName}] Restarting omnileads service...${NoColor}\n"
    systemctl restart omnileads > /dev/null 2>&1
    printf "${Green}*** [${AddonName}] Done!${NoColor}\n"
  else
    printf "${Red}*** [${AddonName}] There was an error during installation. Contact your administrator.${NoColor}\n"
  fi
}
###########

# Start

# Options parsing
for Option in "$@";do
    case ${Option} in
        --accept-eula)
            Answer="yes"
            shift
        ;;
    esac
done

EULA

Install

# End